==> envfile-2.0.0.tgz: package/es5/lib/index.js <==
/* eslint no-sync:0, no-unused-vars:0, no-magic-numbers:0 */
'use strict';

// Requires

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var ambi = require('ambi');
var eachr = require('eachr');
var typeChecker = require('typechecker');
var fsUtil = require('fs');

// Define
module.exports = function () {
	function _class() {
		_classCallCheck(this, _class);
	}

	_createClass(_class, null, [{
		key: 'parseFile',

		// Parse an env file asynchronously
		// next(err,obj)
		value: function parseFile(filePath, next) {
			var _this = this;

			// Read
			fsUtil.readFile(filePath, function (err, data) {
				// Check
				if (err) return next(err); // exit

				// Parse
				_this.parse(data.toString(), next);
			});

			// Chain
			return this;
		}

		// Parse an env file synchronously

	}, {
		key: 'parseFileSync',
		value: function parseFileSync(filePath) {
			// Read
			var data = fsUtil.readFileSync(filePath);

			// Check the result
			if (typeChecker.isError(data)) {
				// An error occured
				return data;
			} else {
				// Parse the result
				return this.parseSync(data.toString());
			}
		}

		// Parse an envfile string
		// next(err,obj)

	}, {
		key: 'parse',
		value: function parse(src, next) {
			var _this2 = this;

			// Call the synchronous method asynchronously and avoid zalgo by wrapping in nextTick
			process.nextTick(function () {
				ambi(_this2.parseSync, src, next);
			});

			// Chain
			return this;
		}

		// Parse an envfile string synchronously

	}, {
		key: 'parseSync',
		value: function parseSync(src) {
			// Try parse JSON
			try {
				return JSON.parse(src.toString());
			}

			// Try parse envfile string
			catch (err) {
				var result = {};
				var lines = src.toString().split('\n');
				var _iteratorNormalCompletion = true;
				var _didIteratorError = false;
				var _iteratorError = undefined;

				try {
					for (var _iterator = lines[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
						var line = _step.value;

						var match = line.match(/^([^=:]+?)[=\:](.*)/);
						if (match) {
							var key = match[1].trim();
							var value = match[2].trim();
							result[key] = value;
						}
					}
				} catch (err) {
					_didIteratorError = true;
					_iteratorError = err;
				} finally {
					try {
						if (!_iteratorNormalCompletion && _iterator.return) {
							_iterator.return();
						}
					} finally {
						if (_didIteratorError) {
							throw _iteratorError;
						}
					}
				}

				return result;
			}
		}

		// Turn an object into envfile string
		// next(err,str)

	}, {
		key: 'stringify',
		value: function stringify(obj, next) {
			var _this3 = this;

			// Call the synchronous method asynchronously and avoid zalgo by wrapping in nextTick
			process.nextTick(function () {
				ambi(_this3.stringifySync, obj, next);
			});

			// Chain
			return this;
		}

		// Turn an object into an envfile synchronously

	}, {
		key: 'stringifySync',
		value: function stringifySync(obj) {
			// Prepare
			var result = '';

			// Stringify
			eachr(obj, function (value, key) {
				if (key) {
					var line = key + '=' + String(value);
					result += line + '\n';
				}
			});

			// Return
			return result;
		}
	}]);

	return _class;
}();

==> envfile-2.0.1.tgz: package/es5/lib/index.js <==
/* eslint no-sync:0, no-unused-vars:0, no-magic-numbers:0 */
'use strict';

// Requires

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var ambi = require('ambi');
var eachr = require('eachr');
var typeChecker = require('typechecker');

// Define
module.exports = function () {
	function _class() {
		_classCallCheck(this, _class);
	}

	_createClass(_class, null, [{
		key: 'parseFile',

		// Parse an env file asynchronously
		// next(err,obj)
		value: function parseFile(filePath, next) {
			var _this = this;

			// Read
			require('fs').readFile(filePath, function (err, data) {
				// Check
				if (err) return next(err); // exit

				// Parse
				_this.parse(data.toString(), next);
			});

			// Chain
			return this;
		}

		// Parse an env file synchronously

	}, {
		key: 'parseFileSync',
		value: function parseFileSync(filePath) {
			// Read
			var data = require('fs').readFileSync(filePath);

			// Check the result
			if (typeChecker.isError(data)) {
				// An error occured
				return data;
			} else {
				// Parse the result
				return this.parseSync(data.toString());
			}
		}

		// Parse an envfile string
		// next(err,obj)

	}, {
		key: 'parse',
		value: function parse(src, next) {
			var _this2 = this;

			// Call the synchronous method asynchronously and avoid zalgo by wrapping in nextTick
			process.nextTick(function () {
				ambi(_this2.parseSync, src, next);
			});

			// Chain
			return this;
		}

		// Parse an envfile string synchronously

	}, {
		key: 'parseSync',
		value: function parseSync(src) {
			// Try parse JSON
			try {
				return JSON.parse(src.toString());
			}

			// Try parse envfile string
			catch (err) {
				var result = {};
				var lines = src.toString().split('\n');
				var _iteratorNormalCompletion = true;
				var _didIteratorError = false;
				var _iteratorError = undefined;

				try {
					for (var _iterator = lines[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
						var line = _step.value;

						var match = line.match(/^([^=:]+?)[=\:](.*)/);
						if (match) {
							var key = match[1].trim();
							var value = match[2].trim();
							result[key] = value;
						}
					}
				} catch (err) {
					_didIteratorError = true;
					_iteratorError = err;
				} finally {
					try {
						if (!_iteratorNormalCompletion && _iterator.return) {
							_iterator.return();
						}
					} finally {
						if (_didIteratorError) {
							throw _iteratorError;
						}
					}
				}

				return result;
			}
		}

		// Turn an object into envfile string
		// next(err,str)

	}, {
		key: 'stringify',
		value: function stringify(obj, next) {
			var _this3 = this;

			// Call the synchronous method asynchronously and avoid zalgo by wrapping in nextTick
			process.nextTick(function () {
				ambi(_this3.stringifySync, obj, next);
			});

			// Chain
			return this;
		}

		// Turn an object into an envfile synchronously

	}, {
		key: 'stringifySync',
		value: function stringifySync(obj) {
			// Prepare
			var result = '';

			// Stringify
			eachr(obj, function (value, key) {
				if (key) {
					var line = key + '=' + String(value);
					result += line + '\n';
				}
			});

			// Return
			return result;
		}
	}]);

	return _class;
}();
